summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:17:52 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:17:52 -0600
commitfcd6d02dc0202443468a21ac982c0f24a1265199 (patch)
tree5e3310de4c224a1e967b9b5d3a2e3690367fff15
parenta42abcb80abc3b4e0f468f4148e7e8c6575cb121 (diff)
downloadbibletime-fcd6d02d.tar.gz
bibletime-fcd6d02d.zip
Rename additional global TQt functions
-rw-r--r--bibletime/backend/bt_gbfhtml.cpp4
-rw-r--r--bibletime/backend/bt_osishtml.cpp8
-rw-r--r--bibletime/backend/cdisplayrendering.cpp4
-rw-r--r--bibletime/backend/cdisplaytemplatemgr.cpp6
-rw-r--r--bibletime/backend/chtmlexportrendering.cpp6
-rw-r--r--bibletime/backend/creferencemanager.cpp8
-rw-r--r--bibletime/backend/cswordbackend.cpp6
-rw-r--r--bibletime/backend/cswordbiblemoduleinfo.cpp2
-rw-r--r--bibletime/backend/cswordcommentarymoduleinfo.cpp2
-rw-r--r--bibletime/backend/cswordkey.cpp4
-rw-r--r--bibletime/backend/cswordldkey.h2
-rw-r--r--bibletime/backend/cswordlexiconmoduleinfo.cpp16
-rw-r--r--bibletime/backend/cswordmoduleinfo.cpp18
-rw-r--r--bibletime/backend/cswordmodulesearch.cpp2
-rw-r--r--bibletime/backend/ctextrendering.cpp2
-rw-r--r--bibletime/bibletime_dcop.cpp22
-rw-r--r--bibletime/bibletime_init.cpp4
-rw-r--r--bibletime/bibletime_slots.cpp2
-rw-r--r--bibletime/frontend/btinstallmgr.cpp10
-rw-r--r--bibletime/frontend/cbtconfig.cpp4
-rw-r--r--bibletime/frontend/cdragdropmgr.cpp16
-rw-r--r--bibletime/frontend/cinfodisplay.cpp12
-rw-r--r--bibletime/frontend/cmdiarea.cpp6
-rw-r--r--bibletime/frontend/cmoduleindexdialog.cpp10
-rw-r--r--bibletime/frontend/coptionsdialog.cpp4
-rw-r--r--bibletime/frontend/cprofile.cpp4
-rw-r--r--bibletime/frontend/crossrefrendering.cpp4
-rw-r--r--bibletime/frontend/cswordsetupdialog.cpp32
-rw-r--r--bibletime/frontend/display/cdisplay.cpp8
-rw-r--r--bibletime/frontend/display/chtmlreaddisplay.cpp4
-rw-r--r--bibletime/frontend/display/chtmlwritedisplay.cpp2
-rw-r--r--bibletime/frontend/display/cplainwritedisplay.cpp2
-rw-r--r--bibletime/frontend/displaywindow/cbiblereadwindow.cpp10
-rw-r--r--bibletime/frontend/displaywindow/cbuttons.cpp2
-rw-r--r--bibletime/frontend/displaywindow/cdisplaywindow.cpp8
-rw-r--r--bibletime/frontend/displaywindow/clexiconreadwindow.cpp6
-rw-r--r--bibletime/frontend/displaywindow/cmodulechooserbutton.cpp2
-rw-r--r--bibletime/frontend/displaywindow/cplainwritewindow.cpp2
-rw-r--r--bibletime/frontend/displaywindow/creadwindow.cpp6
-rw-r--r--bibletime/frontend/displaywindow/cwritewindow.cpp4
-rw-r--r--bibletime/frontend/keychooser/cbiblekeychooser.cpp2
-rw-r--r--bibletime/frontend/keychooser/cbookkeychooser.cpp6
-rw-r--r--bibletime/frontend/keychooser/cbooktreechooser.cpp10
-rw-r--r--bibletime/frontend/keychooser/ckeychooser.cpp10
-rw-r--r--bibletime/frontend/keychooser/ckeychooserwidget.cpp8
-rw-r--r--bibletime/frontend/keychooser/clexiconkeychooser.cpp12
-rw-r--r--bibletime/frontend/kstartuplogo.cpp2
-rw-r--r--bibletime/frontend/mainindex/cindexitem.cpp14
-rw-r--r--bibletime/frontend/mainindex/cmainindex.cpp6
-rw-r--r--bibletime/frontend/searchdialog/cmodulechooser.cpp4
-rw-r--r--bibletime/frontend/searchdialog/crangechooser.cpp4
-rw-r--r--bibletime/frontend/searchdialog/csearchdialog.cpp2
-rw-r--r--bibletime/frontend/searchdialog/csearchdialogpages.cpp2
-rw-r--r--bibletime/frontend/searchdialog/csearchresultview.cpp2
-rw-r--r--bibletime/main.cpp2
-rw-r--r--bibletime/util/ctoolclass.cpp2
-rw-r--r--bibletime/util/directoryutil.cpp8
57 files changed, 186 insertions, 186 deletions
diff --git a/bibletime/backend/bt_gbfhtml.cpp b/bibletime/backend/bt_gbfhtml.cpp
index 3361ce0..1fca87c 100644
--- a/bibletime/backend/bt_gbfhtml.cpp
+++ b/bibletime/backend/bt_gbfhtml.cpp
@@ -134,7 +134,7 @@ char BT_GBFHTML::processText(sword::SWBuf& buf, const sword::SWKey * key, const
for (TQStringList::iterator it = list.begin(); it != list.end(); ++it) {
TQString e = (*it); //current entry to process
- //qWarning(e.latin1());
+ //tqWarning(e.latin1());
//check if there is a word to which the strongs info belongs to.
//If yes, wrap that word with the strongs info
@@ -262,7 +262,7 @@ bool BT_GBFHTML::handleToken(sword::SWBuf &buf, const char *token, sword::BasicF
//we use several append calls because appendFormatted slows down filtering, which should be fast
if (myUserData->hasFootnotePreTag) {
- // qWarning("inserted footnotepre end");
+ // tqWarning("inserted footnotepre end");
buf.append("</span>");
myUserData->hasFootnotePreTag = false;
}
diff --git a/bibletime/backend/bt_osishtml.cpp b/bibletime/backend/bt_osishtml.cpp
index 29441f8..0726bf5 100644
--- a/bibletime/backend/bt_osishtml.cpp
+++ b/bibletime/backend/bt_osishtml.cpp
@@ -72,7 +72,7 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
sword::SWModule* myModule = const_cast<sword::SWModule*>(myUserData->module); //hack
XMLTag tag(token);
- // qWarning("found %s", token);
+ // tqWarning("found %s", token);
const bool osisTQToTick = ((!userData->module->getConfigEntry("OSISqToTick")) || (strcmp(userData->module->getConfigEntry("OSISqToTick"), "false")));
if (!tag.getName()) {
@@ -285,14 +285,14 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
myUserData->noteType = BT_UserData::StrongsMarkup;
}
else if (type == "alternative") {
- // qWarning("found alternative");
+ // tqWarning("found alternative");
// buf.append(" <span class=\"alternative\">");
myUserData->noteType = BT_UserData::Alternative;
myUserData->suspendTextPassThru = true;
myUserData->swordFootnote++; // count as notes, too
}
else {
- // qWarning("found note in %s", myUserData->key->getShortText());
+ // tqWarning("found note in %s", myUserData->key->getShortText());
buf.append(" <span class=\"footnote\" note=\"");
buf.append(myModule->Name());
buf.append('/');
@@ -599,7 +599,7 @@ bool BT_OSISHTML::handleToken(sword::SWBuf &buf, const char *token, sword::Basic
else { // seg end tag
buf.append("</span>");
}
- //qWarning(TQString("handled <seg> token. result: %1").arg(buf.c_str()).latin1());
+ //tqWarning(TQString("handled <seg> token. result: %1").arg(buf.c_str()).latin1());
}
//divine name, don't use simple tag replacing because it may have attributes
diff --git a/bibletime/backend/cdisplayrendering.cpp b/bibletime/backend/cdisplayrendering.cpp
index 48445a9..10ec037 100644
--- a/bibletime/backend/cdisplayrendering.cpp
+++ b/bibletime/backend/cdisplayrendering.cpp
@@ -120,10 +120,10 @@ namespace Rendering {
int pos = text.find(re, 0);
while (pos != -1) { //word begin found
- //qWarning("found word at %i in %i", pos, text.length());
+ //tqWarning("found word at %i in %i", pos, text.length());
int endPos = pos + 1;
if (!CToolClass::inHTMLTag(pos+1, text)) { //the re has a positive look ahead which matches one char before the word start
- //qWarning("matched %s", text.mid(pos+1, 4).latin1());
+ //tqWarning("matched %s", text.mid(pos+1, 4).latin1());
//find end of word and put a marker around it
endPos = text.find(TQRegExp("\\b|[,.:]"), pos+1);
diff --git a/bibletime/backend/cdisplaytemplatemgr.cpp b/bibletime/backend/cdisplaytemplatemgr.cpp
index bb06e49..11104ff 100644
--- a/bibletime/backend/cdisplaytemplatemgr.cpp
+++ b/bibletime/backend/cdisplaytemplatemgr.cpp
@@ -143,7 +143,7 @@ const TQString CDisplayTemplateMgr::fillTemplate( const TQString& name, const TQ
);
}
-// qWarning("Outputing unformated text");
+// tqWarning("Outputing unformated text");
const TQString t = TQString(m_templateMap[ templateName ]) //don't change the map's content directly, use a copy
.replace("#TITLE#", settings.title)
.replace("#LANG_ABBREV#", settings.langAbbrev.isEmpty() ? TQString("en") : settings.langAbbrev)
@@ -168,11 +168,11 @@ const TQString CDisplayTemplateMgr::fillTemplate( const TQString& name, const TQ
\fn CDisplayTemplateMgr::loadUserTemplates
*/
void CDisplayTemplateMgr::loadUserTemplates() {
- qDebug("Loading user templates");
+ tqDebug("Loading user templates");
TQStringList files = KGlobal::dirs()->findAllResources("BT_DisplayTemplates");
for ( TQStringList::iterator it( files.begin() ); it != files.end(); ++it) {
- qDebug("Found user template %s", (*it).latin1());
+ tqDebug("Found user template %s", (*it).latin1());
TQFile f( *it );
Q_ASSERT( f.exists() );
diff --git a/bibletime/backend/chtmlexportrendering.cpp b/bibletime/backend/chtmlexportrendering.cpp
index 2e8c195..dc69b46 100644
--- a/bibletime/backend/chtmlexportrendering.cpp
+++ b/bibletime/backend/chtmlexportrendering.cpp
@@ -36,7 +36,7 @@ namespace Rendering {
CHTMLExportRendering::~CHTMLExportRendering() {}
const TQString CHTMLExportRendering::renderEntry( const KeyTreeItem& i, CSwordKey* k) {
- // qDebug("CHTMLExportRendering::renderEntry");
+ // tqDebug("CHTMLExportRendering::renderEntry");
if (i.hasAlternativeContent()) {
TQString ret;
@@ -128,7 +128,7 @@ namespace Rendering {
const TQString key_renderedText = key->renderedText();
- // qWarning(key_renderedText.latin1());
+ // tqWarning(key_renderedText.latin1());
if (m_filterOptions.headings) {
AttributeValue::const_iterator it =
@@ -197,7 +197,7 @@ namespace Rendering {
renderedText.append("</tr>\n");
}
- // qDebug("CHTMLExportRendering: %s", renderedText.latin1());
+ // tqDebug("CHTMLExportRendering: %s", renderedText.latin1());
return renderedText;
}
diff --git a/bibletime/backend/creferencemanager.cpp b/bibletime/backend/creferencemanager.cpp
index 0c64dbe..a74c4ec 100644
--- a/bibletime/backend/creferencemanager.cpp
+++ b/bibletime/backend/creferencemanager.cpp
@@ -184,7 +184,7 @@ const bool CReferenceManager::decodeHyperlink( const TQString& hyperlink, TQStri
// module = key.left(modPos);
// key = key.mid(modPos+1);
//
- // qWarning("found the module name %s with key %s", module.latin1(), key.latin1());
+ // tqWarning("found the module name %s with key %s", module.latin1(), key.latin1());
// }
//replace \/ escapes with /
@@ -360,7 +360,7 @@ const TQString CReferenceManager::parseVerseReference( const TQString& ref, cons
}
if ((mod->type() != CSwordModuleInfo::Bible) && (mod->type() != CSwordModuleInfo::Commentary)) {
- qDebug("CReferenceManager: Only verse based modules are supported as ref destination module");
+ tqDebug("CReferenceManager: Only verse based modules are supported as ref destination module");
return TQString();
}
@@ -394,7 +394,7 @@ const TQString CReferenceManager::parseVerseReference( const TQString& ref, cons
dummy.setLocale( sourceLanguage.latin1() );
Q_ASSERT( !strcmp(dummy.getLocale(), sourceLanguage.latin1()) );
-// qDebug("Parsing '%s' in '%s' using '%s' as base, source lang '%s', dest lang '%s'", ref.latin1(), options.refDestinationModule.latin1(), baseKey.key().latin1(), sourceLanguage.latin1(), destinationLanguage.latin1());
+// tqDebug("Parsing '%s' in '%s' using '%s' as base, source lang '%s', dest lang '%s'", ref.latin1(), options.refDestinationModule.latin1(), baseKey.key().latin1(), sourceLanguage.latin1(), destinationLanguage.latin1());
for (TQStringList::iterator it = refList.begin(); it != refList.end(); it++) {
//The listkey may contain more than one item, because a ref lik "Gen 1:3,5" is parsed into two single refs
@@ -428,7 +428,7 @@ const TQString CReferenceManager::parseVerseReference( const TQString& ref, cons
}
CPointers::backend()->booknameLanguage(oldLocaleName);
-// qDebug(" %s", ret.latin1());
+// tqDebug(" %s", ret.latin1());
return ret;
}
diff --git a/bibletime/backend/cswordbackend.cpp b/bibletime/backend/cswordbackend.cpp
index 1f19f0d..65df642 100644
--- a/bibletime/backend/cswordbackend.cpp
+++ b/bibletime/backend/cswordbackend.cpp
@@ -72,7 +72,7 @@ CSwordBackend::CSwordBackend()
CSwordBackend::CSwordBackend(const TQString& path, const bool augmentHome)
: sword::SWMgr(!path.isEmpty() ? (const char*)path.local8Bit() : 0, false, new sword::EncodingFilterMgr( sword::ENC_UTF8 ), false, augmentHome) // don't allow module renaming, because we load from a path
{
- qDebug("CSwordBackend::CSwordBackend for %s, using %s", path.latin1(), configPath);
+ tqDebug("CSwordBackend::CSwordBackend for %s, using %s", path.latin1(), configPath);
m_displays.entry = 0;
m_displays.chapter = 0;
m_displays.book = 0;
@@ -100,7 +100,7 @@ CSwordBackend::~CSwordBackend() {
/** Initializes the Sword modules. */
const CSwordBackend::LoadError CSwordBackend::initModules() {
- // qWarning("globalSwordConfigPath is %s", globalConfPath);
+ // tqWarning("globalSwordConfigPath is %s", globalConfPath);
LoadError ret = NoError;
shutdownModules(); //remove previous modules
@@ -677,7 +677,7 @@ const TQStringList CSwordBackend::swordDirList() {
}
void CSwordBackend::filterInit() {
- // qWarning("## INIT");
+ // tqWarning("## INIT");
SWOptionFilter* tmpFilter = new OSISMorphSegmentation();
optionFilters.insert(OptionFilterMap::value_type("OSISMorphSegmentation", tmpFilter));
diff --git a/bibletime/backend/cswordbiblemoduleinfo.cpp b/bibletime/backend/cswordbiblemoduleinfo.cpp
index 04059a5..8f500d3 100644
--- a/bibletime/backend/cswordbiblemoduleinfo.cpp
+++ b/bibletime/backend/cswordbiblemoduleinfo.cpp
@@ -114,7 +114,7 @@ TQStringList* const CSwordBibleModuleInfo::books() {
max = 1;
}
else if (!m_hasOT && !m_hasNT) { //somethings wrong here! - no OT and no NT
- qWarning("CSwordBibleModuleInfo (%s) no OT and not NT! Check your config!", module()->Name());
+ tqWarning("CSwordBibleModuleInfo (%s) no OT and not NT! Check your config!", module()->Name());
min = 0;
max = -1;
}
diff --git a/bibletime/backend/cswordcommentarymoduleinfo.cpp b/bibletime/backend/cswordcommentarymoduleinfo.cpp
index 187ac65..a3a49a6 100644
--- a/bibletime/backend/cswordcommentarymoduleinfo.cpp
+++ b/bibletime/backend/cswordcommentarymoduleinfo.cpp
@@ -25,7 +25,7 @@ CSwordModuleInfo* CSwordCommentaryModuleInfo::clone() {
/** Returns true if this module may be written by the write display windows. */
const bool CSwordCommentaryModuleInfo::isWritable() const {
- // qWarning(module()->getConfigEntry("ModDrv"));
+ // tqWarning(module()->getConfigEntry("ModDrv"));
//a module is only writable if it's a RawFiles module with writable returning true
if ( (std::string(module()->getConfigEntry("ModDrv")) == std::string("RawFiles")) && module()->isWritable()) {
diff --git a/bibletime/backend/cswordkey.cpp b/bibletime/backend/cswordkey.cpp
index a6c5f94..5e13e2b 100644
--- a/bibletime/backend/cswordkey.cpp
+++ b/bibletime/backend/cswordkey.cpp
@@ -54,7 +54,7 @@ const TQString CSwordKey::rawText() {
return TQString();
}
-// qWarning("rawText: %s", m_module->module()->getRawEntry());
+// tqWarning("rawText: %s", m_module->module()->getRawEntry());
return TQString::fromUtf8( m_module->module()->getRawEntry() );
}
@@ -86,7 +86,7 @@ const TQString CSwordKey::renderedText( const CSwordKey::TextRenderType mode ) {
if ( strcasecmp(m_module->module()->getKey()->getText(), buffer)
&& !strstr(m_module->module()->getKey()->getText(), buffer)
) {
- qDebug("return an empty key for %s", m_module->module()->getKey()->getText());
+ tqDebug("return an empty key for %s", m_module->module()->getKey()->getText());
return TQString();
}
}
diff --git a/bibletime/backend/cswordldkey.h b/bibletime/backend/cswordldkey.h
index 303bc06..420301e 100644
--- a/bibletime/backend/cswordldkey.h
+++ b/bibletime/backend/cswordldkey.h
@@ -36,7 +36,7 @@
* CSwordLDKey ldKey(m_module);
* ldKey.key("Adam");
* ldKey.nextEntry();
- * qDebug( TQString("The current key is: %1").arg(ldKey.key()));
+ * tqDebug( TQString("The current key is: %1").arg(ldKey.key()));
* @endcode
*
* Please not, that the result will be invalid if use the operator const char*
diff --git a/bibletime/backend/cswordlexiconmoduleinfo.cpp b/bibletime/backend/cswordlexiconmoduleinfo.cpp
index 5777082..397b75e 100644
--- a/bibletime/backend/cswordlexiconmoduleinfo.cpp
+++ b/bibletime/backend/cswordlexiconmoduleinfo.cpp
@@ -66,7 +66,7 @@ TQStringList* const CSwordLexiconModuleInfo::entries() {
//Check for buggy modules! They will not be loaded any more.
if ( name() == TQString("ZhEnglish")) {
- qWarning("Module ZhEnglish is buggy and will not be loaded.");
+ tqWarning("Module ZhEnglish is buggy and will not be loaded.");
return m_entryList;
}
@@ -89,7 +89,7 @@ TQStringList* const CSwordLexiconModuleInfo::entries() {
}
f1.close();
- // qWarning("read entries %d",m_entryList->count());
+ // tqWarning("read entries %d",m_entryList->count());
}
// Q_ASSERT(read);
@@ -99,13 +99,13 @@ TQStringList* const CSwordLexiconModuleInfo::entries() {
(*my_module) = sword::TOP;
snap(); //snap to top entry
- // qWarning("Reading in module" );
+ // tqWarning("Reading in module" );
int i = 0;
do {
if ( is_unicode ) {
m_entryList->append(TQString::fromUtf8(my_module->KeyText()));
- // qWarning("Entry: %s", my_module->KeyText() );
+ // tqWarning("Entry: %s", my_module->KeyText() );
}
else { //for latin1 modules use fromLatin1 because of speed
// m_entryList->append(TQString::fromLatin1(my_module->KeyText()));
@@ -119,7 +119,7 @@ TQStringList* const CSwordLexiconModuleInfo::entries() {
}
while ( !my_module->Error() );
- // qWarning("Reading finished. Module has %d entries.", i );
+ // tqWarning("Reading finished. Module has %d entries.", i );
(*my_module) = sword::TOP; //back to the first entry
@@ -136,14 +136,14 @@ TQStringList* const CSwordLexiconModuleInfo::entries() {
//now sort the list, this is necesssary because Sword doesn't do Unicode ordering
- // qWarning("sorting");
+ // tqWarning("sorting");
// TQStringList::iterator start(m_entryList->begin());
// TQStringList::iterator end(m_entryList->end());
// std::sort( start, end, myLocaleAwareCompare() ); //stl sort
// m_entryList->sort(); //make sure the module is sorted by utf-8
}
- qWarning("Writing cache file.");
+ tqWarning("Writing cache file.");
if (m_entryList->count()) {
//create cache
@@ -161,7 +161,7 @@ TQStringList* const CSwordLexiconModuleInfo::entries() {
}
}
- // // qWarning("Writing finished." );
+ // // tqWarning("Writing finished." );
}
}
diff --git a/bibletime/backend/cswordmoduleinfo.cpp b/bibletime/backend/cswordmoduleinfo.cpp
index ecb03d0..dc45f1f 100644
--- a/bibletime/backend/cswordmoduleinfo.cpp
+++ b/bibletime/backend/cswordmoduleinfo.cpp
@@ -74,7 +74,7 @@ CSwordModuleInfo::CSwordModuleInfo(sword::SWModule * module, CSwordBackend * con
if (backend()) {
if (hasVersion() && (minimumSwordVersion() > sword::SWVersion::currentVersion)) {
- qWarning("The module \"%s\" requires a newer Sword library. Please update to \"Sword %s\".",
+ tqWarning("The module \"%s\" requires a newer Sword library. Please update to \"Sword %s\".",
name().latin1(), (const char *)minimumSwordVersion());
}
}
@@ -162,18 +162,18 @@ const bool CSwordModuleInfo::unlockKeyIsValid() {
: TQString::fromLatin1( m_module->getRawEntryBuf().c_str() );
if (test.isEmpty()) {
- qWarning("Unlock key of module %s is NOT valid", name().latin1());
+ tqWarning("Unlock key of module %s is NOT valid", name().latin1());
return false;
}
for (unsigned int i = 0; i <= test.length(); i++) {
if ( !test[i].isPrint() && !test[i].isNull() ) {
- qWarning("Unlock key of module %s is NOT valid", name().latin1());
+ tqWarning("Unlock key of module %s is NOT valid", name().latin1());
return false;
}
}
- qDebug("Unlock key of module %s is valid", name().latin1());
+ tqDebug("Unlock key of module %s is valid", name().latin1());
return true;
}
@@ -208,7 +208,7 @@ const bool CSwordModuleInfo::hasIndex() { //this will return true only
}
}
if (indexconfig->readEntry("index-version") != TQString::number( INDEX_VERSION )) {
- qDebug("%s: INDEX_VERSION is not compatible with this version of BibleTime.", name().latin1());
+ tqDebug("%s: INDEX_VERSION is not compatible with this version of BibleTime.", name().latin1());
return false;
}
@@ -293,8 +293,8 @@ void CSwordModuleInfo::buildIndex() {
//If it is a sword-heading, store in buffer and index later in Verse X:1
if (vk) {
if (vk->Verse() == 0) {
- //qWarning("key is %s", key->getText());
- //qWarning("text is %s", m_module->StripText());
+ //tqWarning("key is %s", key->getText());
+ //tqWarning("text is %s", m_module->StripText());
textBuffer.append( m_module->StripText() );
continue;
}
@@ -340,7 +340,7 @@ void CSwordModuleInfo::buildIndex() {
if (attListI->second["LemmaClass"] == "strong") {
lucene_utf8towcs(wcharBuffer, attListI->second["Lemma"], BT_MAX_LUCENE_FIELD_LENGTH);
doc->add(*lucene::document::Field::UnStored(_T("strong"), wcharBuffer));
- //qWarning("Adding strong %s", attListI->second["Lemma"].c_str());
+ //tqWarning("Adding strong %s", attListI->second["Lemma"].c_str());
}
if (attListI->second.find("Morph") != attListI->second.end()) {
lucene_utf8towcs(wcharBuffer, attListI->second["Morph"], BT_MAX_LUCENE_FIELD_LENGTH);
@@ -438,7 +438,7 @@ const bool CSwordModuleInfo::searchIndexed(const TQString& searchedText, sword::
}
}
} catch (...) {
- qWarning("CLucene exception");
+ tqWarning("CLucene exception");
return false;
}
diff --git a/bibletime/backend/cswordmodulesearch.cpp b/bibletime/backend/cswordmodulesearch.cpp
index cc90b6c..0ac21d6 100644
--- a/bibletime/backend/cswordmodulesearch.cpp
+++ b/bibletime/backend/cswordmodulesearch.cpp
@@ -76,7 +76,7 @@ void CSwordModuleSearch::setSearchScope( const sword::ListKey& scope ) {
//disable searching with a scope!
// if (m_searchOptions | useScope) {
- // qWarning("using the scope!");
+ // tqWarning("using the scope!");
//set back the scope flag
// }
}
diff --git a/bibletime/backend/ctextrendering.cpp b/bibletime/backend/ctextrendering.cpp
index 5ce2eed..c5fe9f5 100644
--- a/bibletime/backend/ctextrendering.cpp
+++ b/bibletime/backend/ctextrendering.cpp
@@ -218,7 +218,7 @@ const TQString CTextRendering::renderKeyTree( KeyTree& tree ) {
const TQString CTextRendering::renderKeyRange( const TQString& start, const TQString& stop, const ListCSwordModuleInfo& modules, const TQString& highlightKey, const KeyTreeItem::Settings& keySettings ) {
CSwordModuleInfo* module = modules.first();
- //qWarning( "renderKeyRange start %s stop %s \n", start.latin1(), stop.latin1() );
+ //tqWarning( "renderKeyRange start %s stop %s \n", start.latin1(), stop.latin1() );
util::scoped_ptr<CSwordKey> lowerBound( CSwordKey::createInstance(module) );
lowerBound->key(start);
diff --git a/bibletime/bibletime_dcop.cpp b/bibletime/bibletime_dcop.cpp
index 1d8e798..6318ab7 100644
--- a/bibletime/bibletime_dcop.cpp
+++ b/bibletime/bibletime_dcop.cpp
@@ -23,7 +23,7 @@
//helper function
void BibleTime::syncAllModulesByType(const CSwordModuleInfo::ModuleType type, const TQString& key) {
- qDebug("Syncing modules by type to key %s", key.latin1());
+ tqDebug("Syncing modules by type to key %s", key.latin1());
TQPtrList<TQWidget> windows = m_mdi->usableWindowList();
for (TQWidget* w = windows.first(); w; w = windows.next()) {
@@ -37,34 +37,34 @@ void BibleTime::syncAllModulesByType(const CSwordModuleInfo::ModuleType type, co
}
void BibleTime::closeAllModuleWindows() {
- qDebug("DCOP: close all windows now...");
+ tqDebug("DCOP: close all windows now...");
m_mdi->deleteAll();
}
void BibleTime::syncAllBibles(const TQString& key) {
- qDebug("DCOP: syncing all bibles ...");
+ tqDebug("DCOP: syncing all bibles ...");
syncAllModulesByType(CSwordModuleInfo::Bible, key);
}
void BibleTime::syncAllCommentaries(const TQString& key) {
- qDebug("DCOP: syncing all commentaries ...");
+ tqDebug("DCOP: syncing all commentaries ...");
syncAllModulesByType(CSwordModuleInfo::Commentary, key);
}
void BibleTime::syncAllLexicons(const TQString& key) {
- qDebug("DCOP: syncing all lexicons ...");
+ tqDebug("DCOP: syncing all lexicons ...");
syncAllModulesByType(CSwordModuleInfo::Lexicon, key);
}
void BibleTime::syncAllVerseBasedModules(const TQString& key) {
- qDebug("DCOP: syncing all verse based modules ...");
+ tqDebug("DCOP: syncing all verse based modules ...");
syncAllModulesByType(CSwordModuleInfo::Bible, key);
syncAllModulesByType(CSwordModuleInfo::Commentary, key);
}
void BibleTime::openWindow(const TQString& moduleName, const TQString& key) {
- qDebug("DCOP: open window for module %s and key %s...", moduleName.latin1(), key.latin1());
+ tqDebug("DCOP: open window for module %s and key %s...", moduleName.latin1(), key.latin1());
CSwordModuleInfo* module = CPointers::backend()->findModuleByName(moduleName);
Q_ASSERT(module);
@@ -74,7 +74,7 @@ void BibleTime::openWindow(const TQString& moduleName, const TQString& key) {
}
void BibleTime::openDefaultBible(const TQString& key) {
- qDebug("DCOP: open default bible ...");
+ tqDebug("DCOP: open default bible ...");
CSwordModuleInfo* mod = CBTConfig::get
(CBTConfig::standardBible);
if (mod) {
@@ -83,7 +83,7 @@ void BibleTime::openDefaultBible(const TQString& key) {
}
TQStringList BibleTime::searchInModule(const TQString& moduleName, const TQString& searchText) {
- qDebug("DCOP: searchInModule %s ...", moduleName.latin1());
+ tqDebug("DCOP: searchInModule %s ...", moduleName.latin1());
TQStringList ret;
CSwordModuleInfo* mod = CPointers::backend()->findModuleByName(moduleName);
@@ -117,7 +117,7 @@ TQStringList BibleTime::searchInModule(const TQString& moduleName, const TQStrin
}
TQStringList BibleTime::searchInOpenModules(const TQString& searchText) {
- qDebug("DCOP: search in open modules ...");
+ tqDebug("DCOP: search in open modules ...");
TQStringList ret;
TQWidgetList windows = m_mdi->windowList();
@@ -143,7 +143,7 @@ TQStringList BibleTime::searchInDefaultBible(const TQString& searchText) {
}
TQString BibleTime::getCurrentReference() {
- qDebug("BibleTime::getCurrentReference");
+ tqDebug("BibleTime::getCurrentReference");
TQString ret = TQString();
CDisplayWindow* w = dynamic_cast<CDisplayWindow*>(m_mdi->activeWindow());
diff --git a/bibletime/bibletime_init.cpp b/bibletime/bibletime_init.cpp
index 178ff18..1f86608 100644
--- a/bibletime/bibletime_init.cpp
+++ b/bibletime/bibletime_init.cpp
@@ -272,7 +272,7 @@ void BibleTime::initActions() {
CResMgr::mainMenu::window::arrangementMode::autoCascade::tooltip
);
#if TDE_VERSION_MINOR < 1
- // qWarning("Plug accel");
+ // tqWarning("Plug accel");
m_windowAutoCascade_action->plugAccel( accel() );
#endif
@@ -501,7 +501,7 @@ void BibleTime::initConnections() {
this, TQT_SLOT(slotWindowMenuAboutToShow()));
}
else {
- qWarning("Main window: can't find window menu");
+ tqWarning("Main window: can't find window menu");
}
diff --git a/bibletime/bibletime_slots.cpp b/bibletime/bibletime_slots.cpp
index 1e73427..191bc2c 100644
--- a/bibletime/bibletime_slots.cpp
+++ b/bibletime/bibletime_slots.cpp
@@ -439,7 +439,7 @@ void BibleTime::loadProfile(int ID) {
//HACK: workaround the inserted & char by KPopupMenu
const TQString profileName = popup->text(ID).remove("&");
CProfile* p = m_profileMgr.profile( profileName );
- // qWarning("requesting popup: %s", popup->text(ID).latin1());
+ // tqWarning("requesting popup: %s", popup->text(ID).latin1());
Q_ASSERT(p);
if ( p ) {
diff --git a/bibletime/frontend/btinstallmgr.cpp b/bibletime/frontend/btinstallmgr.cpp
index e819d68..e7a5cdf 100644
--- a/bibletime/frontend/btinstallmgr.cpp
+++ b/bibletime/frontend/btinstallmgr.cpp
@@ -45,7 +45,7 @@ namespace BookshelfManager {
}
TQStringList BTInstallMgr::Tool::RemoteConfig::sourceList( sword::InstallMgr* mgr ) {
- // qWarning("BTInstallMgr::Tool::sourceList( sword::InstallMgr* mgr )");
+ // tqWarning("BTInstallMgr::Tool::sourceList( sword::InstallMgr* mgr )");
Q_ASSERT(mgr);
Q_ASSERT(mgr->installConf);
@@ -218,7 +218,7 @@ namespace BookshelfManager {
ConfigEntMap::iterator it = range.first;
while (it != range.second) {
if (it->second == is->getConfEnt()) {
- // qWarning("found the source!");
+ // tqWarning("found the source!");
config["Sources"].erase(it);
break;
}
@@ -255,11 +255,11 @@ namespace BookshelfManager {
CSwordBackend* ret = 0;
if (RemoteConfig::isRemoteSource(is)) {
- // qWarning("## remote backend for %s", is->localShadow.c_str());
+ // tqWarning("## remote backend for %s", is->localShadow.c_str());
ret = new CSwordBackend( TQString(is->localShadow.c_str()), false );
}
else {
- // qWarning("## local backend for %s", TQString(is->directory.c_str()).latin1());
+ // tqWarning("## local backend for %s", TQString(is->directory.c_str()).latin1());
ret = new CSwordBackend( TQString(is->directory.c_str()) );
}
@@ -327,7 +327,7 @@ namespace BookshelfManager {
}
void BTInstallMgr::preStatus(long totalBytes, long completedBytes, const char* /*message*/) {
- qWarning("pre Status: %i / %i", (int)totalBytes, (int)completedBytes);
+ tqWarning("pre Status: %i / %i", (int)totalBytes, (int)completedBytes);
emit downloadStarted( "unknown filename" );
m_completedBytes = completedBytes;
diff --git a/bibletime/frontend/cbtconfig.cpp b/bibletime/frontend/cbtconfig.cpp
index 2d6d026..5a19a76 100644
--- a/bibletime/frontend/cbtconfig.cpp
+++ b/bibletime/frontend/cbtconfig.cpp
@@ -666,11 +666,11 @@ KConfig* const CBTConfig::getConfig() {
KConfig* config = KGlobal::config();
if (KApplication::kApplication()->sessionSaving()) {
- qWarning("Using session config");
+ tqWarning("Using session config");
// config = KApplication::kApplication()->sessionConfig();
}
else if (KApplication::kApplication()->isRestored()) {
- qWarning("isRestored(): Using session config");
+ tqWarning("isRestored(): Using session config");
}
return config;
diff --git a/bibletime/frontend/cdragdropmgr.cpp b/bibletime/frontend/cdragdropmgr.cpp
index 0179cc5..52d012f 100644
--- a/bibletime/frontend/cdragdropmgr.cpp
+++ b/bibletime/frontend/cdragdropmgr.cpp
@@ -85,7 +85,7 @@ m_text(TQString()) {
vk.setLocale("en");
m_bookmarkKey = vk.key();
- // qWarning("english key of %s is %s", key.latin1(), m_bookmarkKey.latin1());
+ // tqWarning("english key of %s is %s", key.latin1(), m_bookmarkKey.latin1());
}
}
}
@@ -132,7 +132,7 @@ const bool CDragDropMgr::canDecode( const TQMimeSource* const mime ) {
return true;
}
else if( TQTextDrag::canDecode(mime) ) {
- qWarning("TQTextDrag can decode this mime!");
+ tqWarning("TQTextDrag can decode this mime!");
return true;
};
return false;
@@ -169,7 +169,7 @@ TQDragObject* const CDragDropMgr::dragObject( CDragDropMgr::ItemList& items, TQW
}
BTDrag* dragObject = new BTDrag( doc.toString(), dragSource );
- // qWarning("DND data created: %s", (const char*)doc.toString().utf8());
+ // tqWarning("DND data created: %s", (const char*)doc.toString().utf8());
return dragObject;
};
return 0;
@@ -180,7 +180,7 @@ CDragDropMgr::ItemList CDragDropMgr::decode( const TQMimeSource* const src) {
if (canDecode(src) && TQTextDrag::canDecode(src)) { //if we can decode but it's a TQTextDrag and not a BTDrag object
TQString text;
TQTextDrag::decode(src, text);
- // qWarning(text.latin1());
+ // tqWarning(text.latin1());
CDragDropMgr::ItemList dndItems;
dndItems.append( Item(text) );
@@ -194,11 +194,11 @@ CDragDropMgr::ItemList CDragDropMgr::decode( const TQMimeSource* const src) {
BTDrag::decode(src, xmlData);
if (xmlData.isEmpty()) { //something went wrong!
- // qWarning("CDragDropMgr::decode: empty xml data!");
+ // tqWarning("CDragDropMgr::decode: empty xml data!");
return CDragDropMgr::ItemList();
}
// else {
- // qWarning("Drag&Drop data is: %s", xmlData.latin1());
+ // tqWarning("Drag&Drop data is: %s", xmlData.latin1());
// }
//we can handle the dropEvent and have xml data to work on!
@@ -209,14 +209,14 @@ CDragDropMgr::ItemList CDragDropMgr::decode( const TQMimeSource* const src) {
TQDomElement document = doc.documentElement();
if( document.tagName() != "BibleTimeDND" ) { //BibleTime was used in syntax version 1.0
- qWarning("DragDropMgr::decode: Missing BibleTimeDND doc");
+ tqWarning("DragDropMgr::decode: Missing BibleTimeDND doc");
return CDragDropMgr::ItemList();
}
// see if there's a section with the name MAINWINDOW
TQDomElement elem = document.firstChild().toElement();
while (!elem.isNull()) {
if (elem.tagName() == "BOOKMARK") { //we found a bookmark!
- // qWarning("found a bookmark!");
+ // tqWarning("found a bookmark!");
const TQString key = elem.hasAttribute("key") ? elem.attribute("key") : TQString();
const TQString moduleName = elem.hasAttribute("moduleName") ? elem.attribute("moduleName") : TQString();
const TQString description = elem.hasAttribute("description") ? elem.attribute("description") : TQString();
diff --git a/bibletime/frontend/cinfodisplay.cpp b/bibletime/frontend/cinfodisplay.cpp
index f321ccd..7321a83 100644
--- a/bibletime/frontend/cinfodisplay.cpp
+++ b/bibletime/frontend/cinfodisplay.cpp
@@ -71,7 +71,7 @@ namespace InfoDisplay {
CInfoDisplay::~CInfoDisplay() {}
void CInfoDisplay::lookup(const TQString &mod_name, const TQString &key_text) {
- qWarning("%s %s", mod_name.ascii(), key_text.ascii());
+ tqWarning("%s %s", mod_name.ascii(), key_text.ascii());
CSwordModuleInfo* m = CPointers::backend()->findModuleByName(mod_name);
Q_ASSERT(m);
if (!m)
@@ -87,7 +87,7 @@ namespace InfoDisplay {
TQString content = mgr->fillTemplate(CBTConfig::get
(CBTConfig::displayStyle), key->renderedText(), settings);
- // qWarning("setting text:\n%s", content.latin1());
+ // tqWarning("setting text:\n%s", content.latin1());
m_htmlPart->setText(content); // scroll to top
CHTMLReadDisplay *d = dynamic_cast<CHTMLReadDisplay *>(m_htmlPart);
@@ -152,7 +152,7 @@ namespace InfoDisplay {
TQString content = mgr->fillTemplate(CBTConfig::get
(CBTConfig::displayStyle), text, settings);
- // qWarning("setting text:\n%s", content.latin1());
+ // tqWarning("setting text:\n%s", content.latin1());
m_htmlPart->setText(content);
}
@@ -179,7 +179,7 @@ namespace InfoDisplay {
.arg(i18n("Cross references"));
}
- // qWarning("setting crossref %s", data.latin1());
+ // tqWarning("setting crossref %s", data.latin1());
CSwordBackend::DisplayOptions dispOpts;
dispOpts.lineBreaks = false;
@@ -210,7 +210,7 @@ namespace InfoDisplay {
if (pos > 0) {
const TQString moduleName = data.left(pos);
- // qWarning("found module %s", moduleName.latin1());
+ // tqWarning("found module %s", moduleName.latin1());
module = CPointers::backend()->findModuleByName(moduleName);
if (!module) {
module = CBTConfig::get
@@ -266,7 +266,7 @@ namespace InfoDisplay {
tree.append( i );
}
- // qWarning("rendered the tree: %s", renderer.renderKeyTree(tree).latin1());
+ // tqWarning("rendered the tree: %s", renderer.renderKeyTree(tree).latin1());
//spanns containing rtl text need dir=rtl on their parent tag to be aligned properly
return TQString("<div class=\"crossrefinfo\"><h3>%1</h3><div class=\"para\" dir=\"%2\">%3</div></div>")
.arg(i18n("Cross references"))
diff --git a/bibletime/frontend/cmdiarea.cpp b/bibletime/frontend/cmdiarea.cpp
index 8cef49d..dcb951a 100644
--- a/bibletime/frontend/cmdiarea.cpp
+++ b/bibletime/frontend/cmdiarea.cpp
@@ -297,7 +297,7 @@ bool CMDIArea::eventFilter( TQObject *o, TQEvent *e ) {
ret = false;
}
else if (!o->inherits("CDisplayWindow")){
- qDebug("CMDIArea: bad mdi child classname: %s", o->className());
+ tqDebug("CMDIArea: bad mdi child classname: %s", o->className());
//o->dumpObjectInfo();
//o->dumpObjectTree();
}
@@ -310,7 +310,7 @@ bool CMDIArea::eventFilter( TQObject *o, TQEvent *e ) {
\fn CMDIArea::triggerWindowUpdate()
*/
void CMDIArea::triggerWindowUpdate() {
- qDebug("CMDIArea::triggerWindowUpfdate");
+ tqDebug("CMDIArea::triggerWindowUpfdate");
if (isUpdatesEnabled() && usableWindowList().count() ) {
switch (m_guiOption) {
@@ -324,7 +324,7 @@ void CMDIArea::triggerWindowUpdate() {
TQTimer::singleShot(0, this, TQT_SLOT(myCascade()));
break;
default:
- qDebug("CMDIArea::triggerWindowUpdate: no known m_guiType");
+ tqDebug("CMDIArea::triggerWindowUpdate: no known m_guiType");
break;
}
}
diff --git a/bibletime/frontend/cmoduleindexdialog.cpp b/bibletime/frontend/cmoduleindexdialog.cpp
index 55aa596..f42d62c 100644
--- a/bibletime/frontend/cmoduleindexdialog.cpp
+++ b/bibletime/frontend/cmoduleindexdialog.cpp
@@ -32,7 +32,7 @@ CModuleIndexDialog* CModuleIndexDialog::getInstance() {
}
void CModuleIndexDialog::indexAllModules( const ListCSwordModuleInfo& modules ) {
- qDebug("indexAllModules");
+ tqDebug("indexAllModules");
if (modules.count() == 0) {
return;
}
@@ -51,7 +51,7 @@ void CModuleIndexDialog::indexAllModules( const ListCSwordModuleInfo& modules )
(*it)->connectIndexingProgress(this, TQT_SLOT(slotModuleProgress(int)));
progress->setLabel(i18n("Creating index for work %1").arg((*it)->name()));
- qDebug("Building index for work %s", (*it)->name().latin1());
+ tqDebug("Building index for work %s", (*it)->name().latin1());
(*it)->buildIndex();
@@ -64,7 +64,7 @@ void CModuleIndexDialog::indexAllModules( const ListCSwordModuleInfo& modules )
}
void CModuleIndexDialog::indexUnindexedModules( const ListCSwordModuleInfo& modules ) {
- qDebug("indexUnindexedModules");
+ tqDebug("indexUnindexedModules");
ListCSwordModuleInfo unindexedMods;
ListCSwordModuleInfo::const_iterator end_it = modules.end();
@@ -84,14 +84,14 @@ void CModuleIndexDialog::indexUnindexedModules( const ListCSwordModuleInfo& modu
\fn CModuleIndexDialog::slotModuleProgress( int percentage )
*/
void CModuleIndexDialog::slotModuleProgress( int percentage ) {
-// qDebug("progress %d", percentage);
+// tqDebug("progress %d", percentage);
progress->progressBar()->setProgress( m_currentModuleIndex * 100 + percentage );
KApplication::kApplication()->processEvents( 10 ); //10 ms only
}
void CModuleIndexDialog::slotFinished( ) {
- qDebug("indexing finished()");
+ tqDebug("indexing finished()");
progress->progressBar()->setProgress( progress->progressBar()->totalSteps() );
KApplication::kApplication()->processEvents( 1 ); //1 ms only
diff --git a/bibletime/frontend/coptionsdialog.cpp b/bibletime/frontend/coptionsdialog.cpp
index c7e9bfc..c5a5a7c 100644
--- a/bibletime/frontend/coptionsdialog.cpp
+++ b/bibletime/frontend/coptionsdialog.cpp
@@ -243,7 +243,7 @@ void COptionsDialog::initLanguages() {
// locales.push_back(SWBuf("en_US"));
for (list<sword::SWBuf>::const_iterator it = locales.begin(); it != locales.end(); it++) {
- // qWarning("working on %s", (*it).c_str());
+ // tqWarning("working on %s", (*it).c_str());
const CLanguageMgr::Language* const l = CPointers::languageMgr()->languageForAbbrev(
sword::LocaleMgr::getSystemLocaleMgr()->getLocale((*it).c_str())->getName()
);
@@ -829,7 +829,7 @@ void COptionsDialog::saveSword() {
moduleDescription = m_settings.swords.standardGreekMorph->currentText();
break;
default:
- qWarning("Unhandled module type.");
+ tqWarning("Unhandled module type.");
};
CSwordModuleInfo* const module = backend()->findModuleByDescription(moduleDescription);
diff --git a/bibletime/frontend/cprofile.cpp b/bibletime/frontend/cprofile.cpp
index 5d6eb9e..c4f606f 100644
--- a/bibletime/frontend/cprofile.cpp
+++ b/bibletime/frontend/cprofile.cpp
@@ -44,7 +44,7 @@ m_geometry(10,20,640,480) {
init(m_filename);
}
else {
- qWarning("CProfile: empty file name!");
+ tqWarning("CProfile: empty file name!");
}
}
@@ -68,7 +68,7 @@ TQPtrList<CProfileWindow> CProfile::load() {
TQDomElement document = doc.documentElement();
if( document.tagName() != "BibleTimeProfile" && document.tagName() != "BibleTime" ) { //BibleTime was used in syntax version 1.0
- qWarning("CProfile::load: Missing BibleTime doc");
+ tqWarning("CProfile::load: Missing BibleTime doc");
return m_profileWindows;
}
if (document.hasAttribute("name")) {
diff --git a/bibletime/frontend/crossrefrendering.cpp b/bibletime/frontend/crossrefrendering.cpp
index e7bfb5c..2d72fc8 100644
--- a/bibletime/frontend/crossrefrendering.cpp
+++ b/bibletime/frontend/crossrefrendering.cpp
@@ -24,7 +24,7 @@ namespace InfoDisplay {
: CHTMLExportRendering(Settings(), displayOptions, filterOptions) {}
const TQString CrossRefRendering::finishText( const TQString& text, KeyTree& ) {
- // qDebug("CrossRefRendering::finishText");
+ // tqDebug("CrossRefRendering::finishText");
return text;
}
@@ -70,7 +70,7 @@ namespace InfoDisplay {
}
if (!linkText.isEmpty()) { //if we have a valid link text
- // qWarning("rendering");
+ // tqWarning("rendering");
return TQString("<a href=\"%1\">%2</a>")
.arg(
CReferenceManager::encodeHyperlink(
diff --git a/bibletime/frontend/display/cdisplay.cpp b/bibletime/frontend/display/cdisplay.cpp
index 9278455..bc81ada 100644
--- a/bibletime/frontend/display/cdisplay.cpp
+++ b/bibletime/frontend/display/cdisplay.cpp
@@ -65,7 +65,7 @@ void CDisplayConnections::copyAll() {
/** No descriptions */
void CDisplayConnections::copySelection() {
- qWarning("copyign the selected text");
+ tqWarning("copyign the selected text");
m_display->copy(CDisplay::PlainText, CDisplay::SelectedText);
}
@@ -117,7 +117,7 @@ CReadDisplay* CDisplay::createReadInstance( CReadWindow* readWindow, TQWidget* p
}
CWriteDisplay* CDisplay::createWriteInstance( CWriteWindow* writeWindow, const CWriteDisplay::WriteDisplayType& type, TQWidget* parent ) {
- // qWarning("CDisplay::createWriteInstance");
+ // tqWarning("CDisplay::createWriteInstance");
if (type == PlainTextDisplay) {
return new CPlainWriteDisplay(writeWindow, parent);
}
@@ -145,7 +145,7 @@ const bool CDisplay::copy( const CDisplay::TextType format, const CDisplay::Text
}
const bool CDisplay::save( const CDisplay::TextType format, const CDisplay::TextPart part ) {
- // qWarning("CDisplay::save( const CDisplay::TextType format, const CDisplay::TextPart part )");
+ // tqWarning("CDisplay::save( const CDisplay::TextType format, const CDisplay::TextPart part )");
const TQString content = text(format, part);
TQString filter = TQString();
@@ -168,7 +168,7 @@ const bool CDisplay::save( const CDisplay::TextType format, const CDisplay::Text
/** Emits the signal which used when a reference was clicked. */
void CDisplay::emitReferenceClicked( const TQString& reference ) {
- qWarning("reference clicked %s", reference.latin1());
+ tqWarning("reference clicked %s", reference.latin1());
TQString module;
TQString key;
CReferenceManager::Type type;
diff --git a/bibletime/frontend/display/chtmlreaddisplay.cpp b/bibletime/frontend/display/chtmlreaddisplay.cpp
index 6f1997a..d4488c8 100644
--- a/bibletime/frontend/display/chtmlreaddisplay.cpp
+++ b/bibletime/frontend/display/chtmlreaddisplay.cpp
@@ -214,7 +214,7 @@ void CHTMLReadDisplay::moveToAnchor( const TQString& anchor ) {
void CHTMLReadDisplay::urlSelected( const TQString& url, int button, int state, const TQString& _target, KParts::URLArgs args) {
KHTMLPart::urlSelected(url, button, state, _target, args);
m_urlWorkaroundData.doWorkaround = false;
- // qWarning("clicked: %s", url.latin1());
+ // tqWarning("clicked: %s", url.latin1());
if (!url.isEmpty() && CReferenceManager::isHyperlink(url)) {
TQString module;
TQString key;
@@ -479,7 +479,7 @@ void CHTMLReadDisplayView::contentsDragEnterEvent( TQDragEnterEvent* e ) {
void CHTMLReadDisplay::slotGoToAnchor() {
if (!m_currentAnchorCache.isEmpty()) {
if (!gotoAnchor( m_currentAnchorCache ) ) {
- qDebug("anchor %s not present!", m_currentAnchorCache.latin1());
+ tqDebug("anchor %s not present!", m_currentAnchorCache.latin1());
}
}
m_currentAnchorCache = TQString();
diff --git a/bibletime/frontend/display/chtmlwritedisplay.cpp b/bibletime/frontend/display/chtmlwritedisplay.cpp
index b1a74c8..111eb19 100644
--- a/bibletime/frontend/display/chtmlwritedisplay.cpp
+++ b/bibletime/frontend/display/chtmlwritedisplay.cpp
@@ -99,7 +99,7 @@ void CHTMLWriteDisplay::slotAlignmentChanged( int a ) {
// }
else {
alignLeft = true;
- qWarning("unknown alignment %i", a);
+ tqWarning("unknown alignment %i", a);
}
m_actions.alignLeft->setChecked( alignLeft );
diff --git a/bibletime/frontend/display/cplainwritedisplay.cpp b/bibletime/frontend/display/cplainwritedisplay.cpp
index ec4dd2e..6db1d1d 100644
--- a/bibletime/frontend/display/cplainwritedisplay.cpp
+++ b/bibletime/frontend/display/cplainwritedisplay.cpp
@@ -53,7 +53,7 @@ const bool CPlainWriteDisplay::hasSelection() {
}
TQWidget* CPlainWriteDisplay::view() {
- qDebug("CPlainWriteDisplay::view()");
+ tqDebug("CPlainWriteDisplay::view()");
return this;
}
diff --git a/bibletime/frontend/displaywindow/cbiblereadwindow.cpp b/bibletime/frontend/displaywindow/cbiblereadwindow.cpp
index b4b32fa..612ddb9 100644
--- a/bibletime/frontend/displaywindow/cbiblereadwindow.cpp
+++ b/bibletime/frontend/displaywindow/cbiblereadwindow.cpp
@@ -260,7 +260,7 @@ void CBibleReadWindow::setupPopupMenu() {
/** Reimplemented. */
void CBibleReadWindow::updatePopupMenu() {
- qWarning("CBibleReadWindow::updatePopupMenu()");
+ tqWarning("CBibleReadWindow::updatePopupMenu()");
//enable the action depending on the supported module features
// bool hasStrongs = false;
@@ -400,7 +400,7 @@ void CBibleReadWindow::reload() {
}
//refresh the book lists
-// qDebug("lang is %s",backend()->booknameLanguage().latin1());
+// tqDebug("lang is %s",backend()->booknameLanguage().latin1());
verseKey()->setLocale( backend()->booknameLanguage().latin1() );
keyChooser()->refreshContent();
@@ -413,7 +413,7 @@ bool CBibleReadWindow::eventFilter( TQObject* o, TQEvent* e) {
const bool ret = CLexiconReadWindow::eventFilter(o,e);
// Q_ASSERT(o->inherits("CDisplayWindow"));
- // qWarning("class: %s", o->className());
+ // tqWarning("class: %s", o->className());
if (e && (e->type() == TQEvent::FocusIn)) { //sync other windows to this active
/* This is a hack to work around a KHTML problem (similair to the Drag&Drop problem we had):
@@ -437,7 +437,7 @@ void CBibleReadWindow::lookup( CSwordKey* newKey ) {
}
void CBibleReadWindow::syncWindows() {
- // qWarning("syncing windows");
+ // tqWarning("syncing windows");
TQWidgetList windows = mdi()->windowList();
// Q_ASSERT(windows.count());
if (!windows.count()) {
@@ -452,7 +452,7 @@ void CBibleReadWindow::syncWindows() {
w->lookup( key()->key() );
}
/* else {
- qWarning("class sync: %s", w->className());
+ tqWarning("class sync: %s", w->className());
}*/
}
}
diff --git a/bibletime/frontend/displaywindow/cbuttons.cpp b/bibletime/frontend/displaywindow/cbuttons.cpp
index 3c706f3..99f0809 100644
--- a/bibletime/frontend/displaywindow/cbuttons.cpp
+++ b/bibletime/frontend/displaywindow/cbuttons.cpp
@@ -88,7 +88,7 @@
CDisplaySettingsButton::CDisplaySettingsButton(CSwordBackend::DisplayOptions *displaySettings, CSwordBackend::FilterOptions *moduleSettings, const ListCSwordModuleInfo& useModules,TQWidget *parent, const char *name )
: KToolBarButton(CResMgr::displaywindows::displaySettings::icon, 0, parent, name) {
- // qWarning("CDisplaySettingsButton::CDisplaySettingsButton");
+ // tqWarning("CDisplaySettingsButton::CDisplaySettingsButton");
m_displaySettings = displaySettings;
m_moduleSettings = moduleSettings;
m_modules = useModules;
diff --git a/bibletime/frontend/displaywindow/cdisplaywindow.cpp b/bibletime/frontend/displaywindow/cdisplaywindow.cpp
index 8a798e5..6bbbf30 100644
--- a/bibletime/frontend/displaywindow/cdisplaywindow.cpp
+++ b/bibletime/frontend/displaywindow/cdisplaywindow.cpp
@@ -59,7 +59,7 @@ CReadWindow* CDisplayWindow::createReadInstance(ListCSwordModuleInfo modules, CM
case CSwordModuleInfo::GenericBook:
return new CBookReadWindow(modules, parent, name);
default:
- qWarning("unknown module type");
+ tqWarning("unknown module type");
break;
}
return 0;
@@ -440,7 +440,7 @@ void CDisplayWindow::lookup( const TQString& keyName ) {
*/
Q_ASSERT(modules().first());
- //qDebug("CDisplayWindow::lookup: %s", keyName.latin1());
+ //tqDebug("CDisplayWindow::lookup: %s", keyName.latin1());
lookup(modules().first()->name(), keyName);
}
@@ -450,7 +450,7 @@ void CDisplayWindow::updatePopupMenu() {}
///** Returns the installed popup menu. */
KPopupMenu* const CDisplayWindow::popup() {
- // qWarning("CReadWindow::popup()");
+ // tqWarning("CReadWindow::popup()");
if (!m_popupMenu) {
m_popupMenu = new KPopupMenu(this);
connect(m_popupMenu, TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(updatePopupMenu()));
@@ -458,7 +458,7 @@ KPopupMenu* const CDisplayWindow::popup() {
displayWidget()->installPopup(m_popupMenu);
}
/* else {
- qWarning("CDisplayWindow:: can't instal popup menu");
+ tqWarning("CDisplayWindow:: can't instal popup menu");
}*/
}
return m_popupMenu;
diff --git a/bibletime/frontend/displaywindow/clexiconreadwindow.cpp b/bibletime/frontend/displaywindow/clexiconreadwindow.cpp
index 37103a9..330436a 100644
--- a/bibletime/frontend/displaywindow/clexiconreadwindow.cpp
+++ b/bibletime/frontend/displaywindow/clexiconreadwindow.cpp
@@ -279,7 +279,7 @@ void CLexiconReadWindow::saveAsPlain() {
}
void CLexiconReadWindow::slotFillBackHistory() {
- // qWarning("fill back history");
+ // tqWarning("fill back history");
TQStringList keyList = keyChooser()->getPreviousKeys();
TQPopupMenu* menu = m_actions.backInHistory->popupMenu();
menu->clear();
@@ -293,7 +293,7 @@ void CLexiconReadWindow::slotFillBackHistory() {
}
void CLexiconReadWindow::slotFillForwardHistory() {
- // qWarning("fill forward history");
+ // tqWarning("fill forward history");
TQStringList keyList = keyChooser()->getNextKeys();
TQPopupMenu* menu = m_actions.forwardInHistory->popupMenu();
menu->clear();
@@ -308,7 +308,7 @@ void CLexiconReadWindow::slotFillForwardHistory() {
void CLexiconReadWindow::slotUpdateHistoryButtons() {
- // qWarning("updating history buttons");
+ // tqWarning("updating history buttons");
Q_ASSERT(m_actions.backInHistory);
Q_ASSERT(keyChooser());
diff --git a/bibletime/frontend/displaywindow/cmodulechooserbutton.cpp b/bibletime/frontend/displaywindow/cmodulechooserbutton.cpp
index 59d4052..39e904b 100644
--- a/bibletime/frontend/displaywindow/cmodulechooserbutton.cpp
+++ b/bibletime/frontend/displaywindow/cmodulechooserbutton.cpp
@@ -262,7 +262,7 @@ void CModuleChooserButton::updateMenuItems() {
Q_ASSERT(module);
// if (!module) {
-// qWarning("Can't find module with name %s", moduleName.latin1());
+// tqWarning("Can't find module with name %s", moduleName.latin1());
// }
bool alreadyChosen = chosenModules.contains( module );
diff --git a/bibletime/frontend/displaywindow/cplainwritewindow.cpp b/bibletime/frontend/displaywindow/cplainwritewindow.cpp
index 376d917..06cb508 100644
--- a/bibletime/frontend/displaywindow/cplainwritewindow.cpp
+++ b/bibletime/frontend/displaywindow/cplainwritewindow.cpp
@@ -37,7 +37,7 @@ CPlainWriteWindow::~CPlainWriteWindow() {}
/** Initialize the state of this widget. */
void CPlainWriteWindow::initView() {
- // qWarning("CPlainWriteWindow::initView()");
+ // tqWarning("CPlainWriteWindow::initView()");
setDisplayWidget( CDisplay::createWriteInstance(this) );
setCentralWidget( displayWidget()->view() );
diff --git a/bibletime/frontend/displaywindow/creadwindow.cpp b/bibletime/frontend/displaywindow/creadwindow.cpp
index 6a3e803..0b3ab27 100644
--- a/bibletime/frontend/displaywindow/creadwindow.cpp
+++ b/bibletime/frontend/displaywindow/creadwindow.cpp
@@ -43,7 +43,7 @@ m_displayWidget(0) {
}
CReadWindow::~CReadWindow() {
- // qWarning("destructor of CReadWindow");
+ // tqWarning("destructor of CReadWindow");
}
/** Returns the display widget of this window. */
@@ -106,7 +106,7 @@ void CReadWindow::lookup( CSwordKey* newKey ) {
setCaption( windowCaption() );
- // qDebug("[CReadWindow::lookup] Moving to anchor %s", CDisplayRendering::keyToHTMLAnchor(key()->key()).latin1());
+ // tqDebug("[CReadWindow::lookup] Moving to anchor %s", CDisplayRendering::keyToHTMLAnchor(key()->key()).latin1());
displayWidget()->moveToAnchor( CDisplayRendering::keyToHTMLAnchor(key()->key()) );
}
@@ -184,7 +184,7 @@ void CReadWindow::resizeEvent(TQResizeEvent* /*e*/) {
}
void CReadWindow::openSearchStrongsDialog() {
-// qWarning("looking for lemma %s", displayWidget()->getCurrentNodeInfo()[CDisplay::Lemma].latin1() );
+// tqWarning("looking for lemma %s", displayWidget()->getCurrentNodeInfo()[CDisplay::Lemma].latin1() );
TQString searchText = TQString();
if (displayWidget()->getCurrentNodeInfo()[CDisplay::Lemma] != TQString()) {
diff --git a/bibletime/frontend/displaywindow/cwritewindow.cpp b/bibletime/frontend/displaywindow/cwritewindow.cpp
index 760a767..ef9cf71 100644
--- a/bibletime/frontend/displaywindow/cwritewindow.cpp
+++ b/bibletime/frontend/displaywindow/cwritewindow.cpp
@@ -39,7 +39,7 @@ void CWriteWindow::insertKeyboardActions( KActionCollection* const ) {
}
void CWriteWindow::initConnections() {
- // qWarning("CWriteWindow::initConnections()");
+ // tqWarning("CWriteWindow::initConnections()");
Q_ASSERT(keyChooser());
connect(keyChooser(), TQT_SIGNAL(beforeKeyChange(const TQString&)),
@@ -135,7 +135,7 @@ CWriteDisplay* const CWriteWindow::displayWidget() {
/** Saves settings */
bool CWriteWindow::queryClose() {
- // qWarning("queryClose called!");
+ // tqWarning("queryClose called!");
//save the text if it has changed
if (m_writeDisplay->isModified()) {
switch (KMessageBox::warningYesNoCancel( this, i18n("Save text before closing?")) ) {
diff --git a/bibletime/frontend/keychooser/cbiblekeychooser.cpp b/bibletime/frontend/keychooser/cbiblekeychooser.cpp
index 3d1a50e..af8f320 100644
--- a/bibletime/frontend/keychooser/cbiblekeychooser.cpp
+++ b/bibletime/frontend/keychooser/cbiblekeychooser.cpp
@@ -34,7 +34,7 @@ m_key(dynamic_cast<CSwordVerseKey*>(key)) {
w_ref = 0;
setModules(modules, false);
if (!m_modules.count()) {
- qWarning("CBibleKeyChooser: module is not a Bible or commentary!");
+ tqWarning("CBibleKeyChooser: module is not a Bible or commentary!");
m_key = 0;
return;
}
diff --git a/bibletime/frontend/keychooser/cbookkeychooser.cpp b/bibletime/frontend/keychooser/cbookkeychooser.cpp
index 04a3a39..e037290 100644
--- a/bibletime/frontend/keychooser/cbookkeychooser.cpp
+++ b/bibletime/frontend/keychooser/cbookkeychooser.cpp
@@ -43,7 +43,7 @@ void CBookKeyChooser::setKey(CSwordKey* newKey) {
/** Sets a new key to this keychooser */
void CBookKeyChooser::setKey(CSwordKey* newKey, const bool emitSignal) {
- //qDebug("CBookKeyChooser::setKey");
+ //tqDebug("CBookKeyChooser::setKey");
if (m_key != newKey) {
m_key = dynamic_cast<CSwordTreeKey*>(newKey);
}
@@ -76,7 +76,7 @@ void CBookKeyChooser::setKey(CSwordKey* newKey, const bool emitSignal) {
do {
++index;
- //qDebug("set 'found'");
+ //tqDebug("set 'found'");
//found = (TQString::fromLocal8Bit(m_key->getLocalName()) == sibling);
found = (m_key->getLocalNameUnicode() == sibling);
}
@@ -276,7 +276,7 @@ void CBookKeyChooser::keyChooserChanged(int /*newIndex*/) {
newKey.remove(newKey.length(),1); //remove the traling slash
}
- // qWarning("key changed: setting to %s", newKey.latin1());
+ // tqWarning("key changed: setting to %s", newKey.latin1());
m_key->key(newKey);
setKey(m_key);
}
diff --git a/bibletime/frontend/keychooser/cbooktreechooser.cpp b/bibletime/frontend/keychooser/cbooktreechooser.cpp
index 5ce4ce3..d47e298 100644
--- a/bibletime/frontend/keychooser/cbooktreechooser.cpp
+++ b/bibletime/frontend/keychooser/cbooktreechooser.cpp
@@ -29,7 +29,7 @@ CBookTreeChooser::TreeItem::TreeItem(TQListViewItem* parent, TQListViewItem* aft
: KListViewItem(parent, after),
m_key(key),
m_keyName(keyName) {
- //qDebug("first CBookTreeChooser::TreeItem ctor");
+ //tqDebug("first CBookTreeChooser::TreeItem ctor");
const unsigned long offset = m_key->getOffset();
m_key->key(m_keyName);
@@ -43,7 +43,7 @@ CBookTreeChooser::TreeItem::TreeItem(TQListViewItem* parent,CSwordTreeKey* key,
: KListViewItem(parent),
m_key(key),
m_keyName(keyName) {
- //qDebug("second CBookTreeChooser::TreeItem ctor");
+ //tqDebug("second CBookTreeChooser::TreeItem ctor");
const unsigned int offset = m_key->getOffset();
m_key->key(m_keyName);
@@ -57,7 +57,7 @@ CBookTreeChooser::TreeItem::TreeItem(TQListView* view, TQListViewItem* after,CSw
: KListViewItem(view,after),
m_key(key),
m_keyName(keyName) {
- //qDebug("third CBookTreeChooser::TreeItem ctor");
+ //tqDebug("third CBookTreeChooser::TreeItem ctor");
const unsigned int offset = m_key->getOffset();
m_key->key(m_keyName);
@@ -247,11 +247,11 @@ void CBookTreeChooser::adjustFont() {
// if ( m_modules.first()->isUnicode() ){
m_treeView->setFont( CBTConfig::get
(m_modules.first()->language()).second );
- // qWarning("Unicode Book detected");
+ // tqWarning("Unicode Book detected");
// }
// else{
// m_treeView->setFont( CBTConfig::get(CBTConfig::standard) );
- // qWarning("Standard Book detected");
+ // tqWarning("Standard Book detected");
// }
}
diff --git a/bibletime/frontend/keychooser/ckeychooser.cpp b/bibletime/frontend/keychooser/ckeychooser.cpp
index 0db5911..aad247f 100644
--- a/bibletime/frontend/keychooser/ckeychooser.cpp
+++ b/bibletime/frontend/keychooser/ckeychooser.cpp
@@ -54,7 +54,7 @@ void CKeyChooser::backInHistory() {
void CKeyChooser::backInHistory(int count) {
m_inHistoryFunction = true;
- // qWarning("go back %d items in history", count);
+ // tqWarning("go back %d items in history", count);
Q_ASSERT(m_prevKeyHistoryList.size());
@@ -63,7 +63,7 @@ void CKeyChooser::backInHistory(int count) {
//pop_front count items, the top item is then the new current key
int index = count;
while ((index > 0) && (it != m_prevKeyHistoryList.end())) {
- // qWarning("pop_front");
+ // tqWarning("pop_front");
m_nextKeyHistoryList.prepend(*it);
it = m_prevKeyHistoryList.remove(it);
@@ -86,7 +86,7 @@ void CKeyChooser::forwardInHistory() {
void CKeyChooser::forwardInHistory(int count) {
m_inHistoryFunction = true;
- // qWarning("go forward %d items in history", count);
+ // tqWarning("go forward %d items in history", count);
Q_ASSERT(m_nextKeyHistoryList.size());
@@ -94,7 +94,7 @@ void CKeyChooser::forwardInHistory(int count) {
//pop_front count-1 items, the top item is then the new current key
int index = count;
while (index > 0 && it != m_nextKeyHistoryList.end()) {
- // qWarning("pop_front");
+ // tqWarning("pop_front");
m_prevKeyHistoryList.prepend(*it);
it = m_nextKeyHistoryList.remove(it);
@@ -113,7 +113,7 @@ void CKeyChooser::forwardInHistory(int count) {
}
void CKeyChooser::addToHistory(CSwordKey* k) {
- // qWarning("addToHistory");
+ // tqWarning("addToHistory");
Q_ASSERT(!m_inHistoryFunction);
if (k && !m_inHistoryFunction) {
diff --git a/bibletime/frontend/keychooser/ckeychooserwidget.cpp b/bibletime/frontend/keychooser/ckeychooserwidget.cpp
index 25b43f2..38df7d7 100644
--- a/bibletime/frontend/keychooser/ckeychooserwidget.cpp
+++ b/bibletime/frontend/keychooser/ckeychooserwidget.cpp
@@ -141,7 +141,7 @@ void CKeyChooserWidget::reset(TQStringList *list, int index, bool do_emit) {
if (isResetting || !isUpdatesEnabled())
return;
- // qWarning("starting insert");
+ // tqWarning("starting insert");
isResetting = true;
oldKey = TQString();
@@ -176,7 +176,7 @@ void CKeyChooserWidget::reset(TQStringList *list, int index, bool do_emit) {
// m_comboBox->setUpdatesEnabled(true);
isResetting = false;
- // qWarning("inserted");
+ // tqWarning("inserted");
}
/** Initializes this widget. We need this function because we have more than one constructor. */
@@ -216,7 +216,7 @@ void CKeyChooserWidget::init() {
/** Is called when the return key was presed in the combobox. */
void CKeyChooserWidget::slotReturnPressed( /*const TQString& text*/) {
Q_ASSERT(comboBox()->lineEdit());
- qWarning("return pressed");
+ tqWarning("return pressed");
TQString text = comboBox()->lineEdit()->text();
for (int index = 0; index < comboBox()->count(); ++index) {
@@ -230,7 +230,7 @@ void CKeyChooserWidget::slotReturnPressed( /*const TQString& text*/) {
/** Is called when the current item of the combo box was changed. */
void CKeyChooserWidget::slotComboChanged(int index) {
- qWarning("CKeyChooserWidget::slotComboChanged(int index)");
+ tqWarning("CKeyChooserWidget::slotComboChanged(int index)");
if (!isUpdatesEnabled()) {
return;
}
diff --git a/bibletime/frontend/keychooser/clexiconkeychooser.cpp b/bibletime/frontend/keychooser/clexiconkeychooser.cpp
index 1e85d6d..9c8c174 100644
--- a/bibletime/frontend/keychooser/clexiconkeychooser.cpp
+++ b/bibletime/frontend/keychooser/clexiconkeychooser.cpp
@@ -64,7 +64,7 @@ m_key(dynamic_cast<CSwordLDKey*>(key)) {
}
CSwordKey* const CLexiconKeyChooser::key() {
- // qWarning("key");
+ // tqWarning("key");
return m_key;
}
@@ -73,17 +73,17 @@ void CLexiconKeyChooser::setKey(CSwordKey* key) {
return;
}
- // qWarning("setKey start");
+ // tqWarning("setKey start");
TQString newKey = m_key->key();
const int index = m_widget->comboBox()->listBox()->index(m_widget->comboBox()->listBox()->findItem( newKey ));
m_widget->comboBox()->setCurrentItem(index);
- // qWarning("setKey end");
+ // tqWarning("setKey end");
emit keyChanged( m_key );
}
void CLexiconKeyChooser::activated(int index) {
- // qWarning("activated");
+ // tqWarning("activated");
const TQString text = m_widget->comboBox()->text(index);
// To prevent from eternal loop, because activated() is emitted again
@@ -91,7 +91,7 @@ void CLexiconKeyChooser::activated(int index) {
m_key->key(text);
setKey(m_key);
}
- // qWarning("activated end");
+ // tqWarning("activated end");
}
inline const bool my_cmpEntries(const TQString& a, const TQString& b) {
@@ -102,7 +102,7 @@ inline const bool my_cmpEntries(const TQString& a, const TQString& b) {
void CLexiconKeyChooser::refreshContent() {
if (m_modules.count() == 1) {
m_widget->reset(m_modules.first()->entries(), 0, true);
- // qWarning("resetted");
+ // tqWarning("resetted");
}
else {
typedef std::multimap<unsigned int, TQStringList*> EntryMap;
diff --git a/bibletime/frontend/kstartuplogo.cpp b/bibletime/frontend/kstartuplogo.cpp
index f15a483..0609537 100644
--- a/bibletime/frontend/kstartuplogo.cpp
+++ b/bibletime/frontend/kstartuplogo.cpp
@@ -60,7 +60,7 @@ KStartupLogo::KStartupLogo()
TQPixmap pm;
if ( !pm.load(locate("BT_pic","startuplogo.png")) ) {
- qWarning("Can't load startuplogo! Check your installation.");
+ tqWarning("Can't load startuplogo! Check your installation.");
}
setBackgroundPixmap(pm);
diff --git a/bibletime/frontend/mainindex/cindexitem.cpp b/bibletime/frontend/mainindex/cindexitem.cpp
index ff35466..f555e12 100644
--- a/bibletime/frontend/mainindex/cindexitem.cpp
+++ b/bibletime/frontend/mainindex/cindexitem.cpp
@@ -198,7 +198,7 @@ void CModuleItem::dropped( TQDropEvent* e, TQListViewItem* /*after*/) {
CDragDropMgr::ItemList dndItems = CDragDropMgr::decode(e);
CDragDropMgr::Item item = dndItems.first();
if (CDragDropMgr::dndType(e) == CDragDropMgr::Item::Text) { //open the searchdialog
- // qWarning("Text dropped!");
+ // tqWarning("Text dropped!");
if ( module() ) {
ListCSwordModuleInfo modules;
modules.append(module());
@@ -324,7 +324,7 @@ const TQString CBookmarkItem::toolTip() {
Q_ASSERT(k.get());
if (fontPair.first) { //use a special font
- qWarning("using a font, %s", TQString(fontPair.second.family()).latin1());
+ tqWarning("using a font, %s", TQString(fontPair.second.family()).latin1());
ret = TQString::fromLatin1("<b>%1 (%2)</b><br/><small>%3</small><hr><font face=\"%4\" size=\"4\">%5</font>")
.arg(key())
.arg(module()->name())
@@ -620,7 +620,7 @@ setText(0, !language().isEmpty() ? ( lang->isValid() ? lang->translatedName() :
}
void CTreeFolder::initTree() {
- // qWarning("CTreeMgr::initTree");
+ // tqWarning("CTreeMgr::initTree");
if (type() == Unknown)
return;
@@ -728,7 +728,7 @@ namespace Bookmarks {
while ( (it_groups != groupList.end()) && (it_parents != parentList.end()) ) {
TQDomElement parentElement = (*it_parents == -1) ? content : parentMap[*it_parents];
if (parentElement.isNull()) {
- qWarning("EMPTY PARENT FOUND!");
+ tqWarning("EMPTY PARENT FOUND!");
parentElement = content;
};
@@ -761,7 +761,7 @@ namespace Bookmarks {
) {
TQDomElement parentElement = ((*it_parents) == -1) ? content : parentMap[(*it_parents)];
if (parentElement.isNull()) {
- qWarning("EMPTY PARENT FOUND!");
+ tqWarning("EMPTY PARENT FOUND!");
parentElement = content;
};
TQDomElement elem = doc.createElement("Bookmark");
@@ -989,7 +989,7 @@ void CBookmarkFolder::importBookmarks() {
}
bool CBookmarkFolder::acceptDrop(const TQMimeSource * src) const {
- // qWarning("bool CBookmarkFolder::acceptDrop(const TQMimeSource * src): return%ii", (CDragDropMgr::canDecode(src) && (CDragDropMgr::dndType(src) == CDragDropMgr::Item::Bookmark)));
+ // tqWarning("bool CBookmarkFolder::acceptDrop(const TQMimeSource * src): return%ii", (CDragDropMgr::canDecode(src) && (CDragDropMgr::dndType(src) == CDragDropMgr::Item::Bookmark)));
return CDragDropMgr::canDecode(src)
&& (CDragDropMgr::dndType(src) == CDragDropMgr::Item::Bookmark);
@@ -1052,7 +1052,7 @@ const bool CBookmarkFolder::loadBookmarksFromXML( const TQString& xml ) {
doc.setContent(xml);
TQDomElement document = doc.documentElement();
if( document.tagName() != "SwordBookmarks" ) {
- qWarning("Not a BibleTime Bookmark XML file");
+ tqWarning("Not a BibleTime Bookmark XML file");
return false;
}
diff --git a/bibletime/frontend/mainindex/cmainindex.cpp b/bibletime/frontend/mainindex/cmainindex.cpp
index 9558692..28beb6e 100644
--- a/bibletime/frontend/mainindex/cmainindex.cpp
+++ b/bibletime/frontend/mainindex/cmainindex.cpp
@@ -608,7 +608,7 @@ void CMainIndex::startDrag() {
/** Reimplementation to support the items dragEnter and dragLeave functions. */
void CMainIndex::contentsDragMoveEvent( TQDragMoveEvent* event ) {
- // qWarning("void CMainIndex:: drag move event ( TQDragLeaveEvent* e )");
+ // tqWarning("void CMainIndex:: drag move event ( TQDragLeaveEvent* e )");
CItemBase* i = dynamic_cast<CItemBase*>( itemAt( contentsToViewport(event->pos())) );
if (i) {
if (i->allowAutoOpen(event) || (i->acceptDrop(event) && i->isFolder() && i->allowAutoOpen(event) && !i->isOpen() && autoOpen()) ) {
@@ -689,7 +689,7 @@ const bool CMainIndex::isMultiAction( const CItemBase::MenuAction type ) const {
/** Is called when items should be moved. */
void CMainIndex::moved( TQPtrList<TQListViewItem>& /*items*/, TQPtrList<TQListViewItem>& /*afterFirst*/, TQPtrList<TQListViewItem>& /*afterNow*/) {
- qDebug("move items");
+ tqDebug("move items");
}
/** Opens an editor window to edit the modules content. */
@@ -758,7 +758,7 @@ void CMainIndex::saveBookmarks() {
}
void CMainIndex::readSettings() {
- qDebug("CMainIndex::readSettings");
+ tqDebug("CMainIndex::readSettings");
TQStringList openGroups = CBTConfig::get(CBTConfig::bookshelfOpenGroups);
for (TQStringList::Iterator it( openGroups.begin() ); it != openGroups.end(); ++it) {
diff --git a/bibletime/frontend/searchdialog/cmodulechooser.cpp b/bibletime/frontend/searchdialog/cmodulechooser.cpp
index 7b16131..b1decd4 100644
--- a/bibletime/frontend/searchdialog/cmodulechooser.cpp
+++ b/bibletime/frontend/searchdialog/cmodulechooser.cpp
@@ -252,13 +252,13 @@ ListCSwordModuleInfo CModuleChooser::modules() {
/** Sets the list of modules and updates the state of the checkbox items. */
void CModuleChooser::setModules( ListCSwordModuleInfo modules ) {
- // qWarning("CModuleChooser::setModules( ListCSwordModuleInfo modules )");
+ // tqWarning("CModuleChooser::setModules( ListCSwordModuleInfo modules )");
TQListViewItemIterator it( this );
for ( ; it.current(); ++it ) {
if ( ModuleCheckBoxItem* i = dynamic_cast<ModuleCheckBoxItem*>(it.current()) ) {
i->setOn(modules.contains(i->module())); //set the status for the module checkbox item
// if (i->isOn()) { //if it's checked, show the item
- // qWarning("show item!");
+ // tqWarning("show item!");
// ensureItemVisible(i);
// }
}
diff --git a/bibletime/frontend/searchdialog/crangechooser.cpp b/bibletime/frontend/searchdialog/crangechooser.cpp
index deca3ec..dcab174 100644
--- a/bibletime/frontend/searchdialog/crangechooser.cpp
+++ b/bibletime/frontend/searchdialog/crangechooser.cpp
@@ -53,7 +53,7 @@ CRangeChooserDialog::RangeItem::RangeItem(TQListView* view, TQListViewItem* afte
CRangeChooserDialog::RangeItem::~RangeItem() {}
const TQString& CRangeChooserDialog::RangeItem::range() {
- // qWarning("ange is %s", (const char*)m_range.utf8());
+ // tqWarning("ange is %s", (const char*)m_range.utf8());
return m_range;
}
@@ -196,7 +196,7 @@ void CRangeChooserDialog::parseRange() {
sword::ListKey verses = key.ParseVerseList((const char*)range.utf8(), "Genesis 1:1", true);
for (int i = 0; i < verses.Count(); ++i) {
new KListViewItem(m_resultList, TQString::fromUtf8(verses.GetElement(i)->getRangeText()));
- // qWarning("range=%s, text=%s",verses.GetElement(i)->getRangeText(), verses.GetElement(i)->getText() );
+ // tqWarning("range=%s, text=%s",verses.GetElement(i)->getRangeText(), verses.GetElement(i)->getText() );
}
}
diff --git a/bibletime/frontend/searchdialog/csearchdialog.cpp b/bibletime/frontend/searchdialog/csearchdialog.cpp
index ac0c6c6..0039a8f 100644
--- a/bibletime/frontend/searchdialog/csearchdialog.cpp
+++ b/bibletime/frontend/searchdialog/csearchdialog.cpp
@@ -226,7 +226,7 @@ void CSearchDialog::initView() {
}
void CSearchDialog::searchFinished() {
-// qWarning("CSearchDialog::searchFinished()");
+// tqWarning("CSearchDialog::searchFinished()");
if ( m_searcher.foundItems() ) {
m_searchResultPage->setSearchResult(modules());
diff --git a/bibletime/frontend/searchdialog/csearchdialogpages.cpp b/bibletime/frontend/searchdialog/csearchdialogpages.cpp
index b7769b8..1a4f70a 100644
--- a/bibletime/frontend/searchdialog/csearchdialogpages.cpp
+++ b/bibletime/frontend/searchdialog/csearchdialogpages.cpp
@@ -547,7 +547,7 @@ const TQString CSearchResultPage::highlightSearchedText(const TQString& content,
index += length;
}
}
- //qWarning("\n\n\n%s", ret.latin1());
+ //tqWarning("\n\n\n%s", ret.latin1());
return ret;
};
diff --git a/bibletime/frontend/searchdialog/csearchresultview.cpp b/bibletime/frontend/searchdialog/csearchresultview.cpp
index 51c9492..1e9dd38 100644
--- a/bibletime/frontend/searchdialog/csearchresultview.cpp
+++ b/bibletime/frontend/searchdialog/csearchresultview.cpp
@@ -148,7 +148,7 @@ void CSearchResultView::setupStrongsTree(CSwordModuleInfo* m, TQStringList* vLis
/** Is connected to the signal executed, which is emitted when a mew item was chosen. */
void CSearchResultView::executed(TQListViewItem* item) {
// Q_ASSERT(item);
- // qWarning("executed");
+ // tqWarning("executed");
emit keySelected(item->text(0));
}
diff --git a/bibletime/main.cpp b/bibletime/main.cpp
index 56c8ecd..1ec572a 100644
--- a/bibletime/main.cpp
+++ b/bibletime/main.cpp
@@ -246,7 +246,7 @@ int main(int argc, char* argv[]) {
}
if (kapp->isRestored()) {
- // qWarning("Restoring BibleTime");
+ // tqWarning("Restoring BibleTime");
//RESTORE( BibleTime );
int n = 1;
while (KMainWindow::canBeRestored(n)){
diff --git a/bibletime/util/ctoolclass.cpp b/bibletime/util/ctoolclass.cpp
index c20a738..fb2868a 100644
--- a/bibletime/util/ctoolclass.cpp
+++ b/bibletime/util/ctoolclass.cpp
@@ -181,7 +181,7 @@ bool CToolClass::inHTMLTag(int pos, TQString & text) {
if ((i3>0) && (i4==-1)) //we're in the last html tag
i4=i3+1;
- // qWarning("%d > %d && %d < %d",i1,i2,i3,i4);
+ // tqWarning("%d > %d && %d < %d",i1,i2,i3,i4);
if ( (i1>i2) && (i3<i4) )
return true; //yes, we're in a tag
diff --git a/bibletime/util/directoryutil.cpp b/bibletime/util/directoryutil.cpp
index 927cf2a..2f896f4 100644
--- a/bibletime/util/directoryutil.cpp
+++ b/bibletime/util/directoryutil.cpp
@@ -20,7 +20,7 @@ namespace util {
namespace filesystem {
void DirectoryUtil::removeRecursive(const TQString& dir) {
- qWarning("removeRecursive(%s)", dir.latin1());
+ tqWarning("removeRecursive(%s)", dir.latin1());
if (dir == TQString()) {
return;
}
@@ -40,7 +40,7 @@ void DirectoryUtil::removeRecursive(const TQString& dir) {
while ( (fi = it_file.current()) != 0 ) {
++it_file;
- qDebug("Removing %s", fi->absFilePath().latin1() );
+ tqDebug("Removing %s", fi->absFilePath().latin1() );
d.remove( fi->fileName() ) ;
}
@@ -56,7 +56,7 @@ void DirectoryUtil::removeRecursive(const TQString& dir) {
continue;
}
- qDebug("Removing dir %s", fi->absFilePath().latin1() );
+ tqDebug("Removing dir %s", fi->absFilePath().latin1() );
//d.remove( fi->fileName() ) ;
removeRecursive( fi->absFilePath() );
@@ -68,7 +68,7 @@ void DirectoryUtil::removeRecursive(const TQString& dir) {
/** Returns the size of the directory including the size of all it's files and it's subdirs.
*/
unsigned long DirectoryUtil::getDirSizeRecursive(const TQString& dir) {
- qWarning("Getting size for %s", dir.latin1());
+ tqWarning("Getting size for %s", dir.latin1());
TQDir d(dir);
if (!d.exists()) {
diff --git a/bibletime/frontend/cswordsetupdialog.cpp b/bibletime/frontend/cswordsetupdialog.cpp
index 74bf217..d1b7c29 100644
--- a/bibletime/frontend/cswordsetupdialog.cpp
+++ b/bibletime/frontend/cswordsetupdialog.cpp
@@ -508,7 +508,7 @@ the module remote installation feature!</b>")
success = true;
}
else { //an error occurres, the KIO library should display an error message
- qWarning("InstallMgr: refreshRemoteSources returned an error.");
+ tqWarning("InstallMgr: refreshRemoteSources returned an error.");
m_refreshedRemoteSources = false;
success = false;
}
@@ -540,17 +540,17 @@ the module remote installation feature!</b>")
if (BTInstallMgr::Tool::RemoteConfig::isRemoteSource(&is)
&& !refreshRemoteModuleCache(sourceName)) {
- // qWarning("finish");
+ // tqWarning("finish");
m_installModuleListView->finish();
return false;
}
//kind of a hack to provide a pointer to mgr next line
- // qWarning("createing remote_backend");
+ // tqWarning("createing remote_backend");
util::scoped_ptr<CSwordBackend> remote_backend( BTInstallMgr::Tool::backend(&is) );
// qWarning("config path1 is %s", remote_backend->configPath);
// qWarning("config path2 is %s", BTInstallMgr::Tool::backend(&is)->configPath ); //mem leak
// qWarning("after creating remote_backend");
Q_ASSERT(remote_backend);
Q_ASSERT( BTInstallMgr::Tool::RemoteConfig::isRemoteSource(&is) );
if (!remote_backend) {
@@ -560,22 +560,22 @@ the module remote installation feature!</b>")
CSwordBackend* local_backend = CPointers::backend();
Q_ASSERT(local_backend);
- // qWarning("local backend has path %s", local_backend->);
+ // tqWarning("local backend has path %s", local_backend->);
KApplication::kApplication()->processEvents();
//local_backend.initModules();
- // qWarning("config path3 is %s", remote_backend->configPath);
+ // tqWarning("config path3 is %s", remote_backend->configPath);
ListCSwordModuleInfo mods = remote_backend->moduleList();
Q_ASSERT(mods.count() > 0);
ListCSwordModuleInfo::iterator end_it = mods.end();
for (ListCSwordModuleInfo::iterator it(mods.begin()); it != end_it; ++it) {
- // qWarning("adding module %s (%s)", (*it)->name().latin1(), (*it)->config(CSwordModuleInfo::AbsoluteDataPath).latin1());
+ // tqWarning("adding module %s (%s)", (*it)->name().latin1(), (*it)->config(CSwordModuleInfo::AbsoluteDataPath).latin1());
bool isUpdate = false;
CSwordModuleInfo* const installedModule = local_backend->findModuleByName((*it)->name());
if (installedModule) {
- // qWarning("module is already installed in %s", installedModule->config(CSwordModuleInfo::AbsoluteDataPath).latin1());
+ // tqWarning("module is already installed in %s", installedModule->config(CSwordModuleInfo::AbsoluteDataPath).latin1());
}
// Q_ASSERT(installedModule);
@@ -591,7 +591,7 @@ the module remote installation feature!</b>")
isUpdate = (newVersion > installedVersion);
if (!isUpdate) {
- // qWarning(" mod %s is not an update", (*it)->name().latin1());
+ // tqWarning(" mod %s is not an update", (*it)->name().latin1());
continue;
}
}
@@ -684,7 +684,7 @@ the module remote installation feature!</b>")
}
void CSwordSetupDialog::slot_installModules() {
- qWarning("CSwordSetupDialog::slot_installModules()");
+ tqWarning("CSwordSetupDialog::slot_installModules()");
// m_installContinueButton->setEnabled(false);
// m_installBackButton->setEnabled(false);
@@ -703,7 +703,7 @@ the module remote installation feature!</b>")
m_currentInstallMgr = &iMgr;
sword::InstallSource is = BTInstallMgr::Tool::RemoteConfig::source(&iMgr, currentInstallSource());
- qWarning("installing from %s/%s", is.source.c_str(), is.directory.c_str());
+ tqWarning("installing from %s/%s", is.source.c_str(), is.directory.c_str());
TQString target = m_targetCombo->currentText();
//make sure target/mods.d and target/modules exist
@@ -740,7 +740,7 @@ the module remote installation feature!</b>")
for ( TQStringList::Iterator it = moduleList.begin(); (it != moduleList.end()) && !m_progressDialog->wasCancelled(); ++it, ++m_installedModuleCount ) {
- qWarning("installing %s", (*it).latin1());
+ tqWarning("installing %s", (*it).latin1());
m_installingModule = *it;
//check whether it's an update. If yes, remove existing module first
@@ -767,9 +767,9 @@ the module remote installation feature!</b>")
if (!m_progressDialog->wasCancelled()
&& BTInstallMgr::Tool::RemoteConfig::isRemoteSource(&is)) {
- // qWarning("calling install");
+ // tqWarning("calling install");
int status = iMgr.installModule(&lMgr, 0, (*it).latin1(), &is);
- // qWarning("status: %d", status);
+ // tqWarning("status: %d", status);
Q_ASSERT(status != -1);
}
else if (!m_progressDialog->wasCancelled()) { //local source
@@ -540,17 +540,17 @@ the module remote installation feature!</b>")
util::scoped_ptr<CSwordBackend> remote_backend( BTInstallMgr::Tool::backend(&is) );
- // qWarning("config path1 is %s", remote_backend->configPath);
- // qWarning("config path2 is %s", BTInstallMgr::Tool::backend(&is)->configPath ); //mem leak
- // qWarning("after creating remote_backend");
+ // tqWarning("config path1 is %s", remote_backend->configPath);
+ // tqWarning("config path2 is %s", BTInstallMgr::Tool::backend(&is)->configPath ); //mem leak
+ // tqWarning("after creating remote_backend");
Q_ASSERT(remote_backend);
Q_ASSERT( BTInstallMgr::Tool::RemoteConfig::isRemoteSource(&is) );